==> qore-0.9.4.5.tar.bz2: qore-0.9.4.5/lib/parser.hpp <==
/* A Bison parser, made by GNU Bison 3.6.  */

/* Bison interface for Yacc-like parsers in C

   Copyright (C) 1984, 1989-1990, 2000-2015, 2018-2020 Free Software Foundation,
   Inc.

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */

/* As a special exception, you may create a larger work that contains
   part or all of the Bison parser skeleton and distribute that work
   under terms of your choice, so long as that work isn't itself a
   parser generator using the skeleton or a modified version thereof
   as a parser skeleton.  Alternatively, if you modify or redistribute
   the parser skeleton itself, you may (at your option) remove this
   special exception, which will cause the skeleton and the resulting
   Bison output files to be licensed under the GNU General Public
   License without this special exception.

   This special exception was added by the Free Software Foundation in
   version 2.2 of Bison.  */

/* DO NOT RELY ON FEATURES THAT ARE NOT DOCUMENTED in the manual,
   especially those whose name start with YY_ or yy_.  They are
   private implementation details that can be changed or removed.  */

#ifndef YY_YY_PARSER_HPP_INCLUDED
# define YY_YY_PARSER_HPP_INCLUDED
/* Debug traces.  */
#ifndef YYDEBUG
# define YYDEBUG 0
#endif
#if YYDEBUG
extern int yydebug;
#endif

/* Token kinds.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
  enum yytokentype
  {
    YYEMPTY = -2,
    YYEOF = 0,                     /* "end of file"  */
    YYerror = 256,                 /* error  */
    YYUNDEF = 257,                 /* "invalid token"  */
    TOK_RETURN = 258,              /* "return"  */
    TOK_RETURNS = 259,             /* "returns"  */
    TOK_MY = 260,                  /* "my"  */
    TOK_DO = 261,                  /* "do"  */
    TOK_TRY = 262,                 /* "try"  */
    TOK_THROW = 263,               /* "throw"  */
    TOK_CATCH = 264,               /* "catch"  */
    TOK_WHERE = 265,               /* "where"  */
    TOK_WHILE = 266,               /* "while"  */
    TOK_IF = 267,                  /* "if"  */
    TOK_FOR = 268,                 /* "for"  */
    TOK_SUB = 269,                 /* "sub"  */
    TOK_THREAD_EXIT = 270,         /* "thread_exit"  */
    TOK_BREAK = 271,               /* "break"  */
    TOK_CONTINUE = 272,            /* "continue"  */
    TOK_CONTEXT_ROW = 273,         /* "%%"  */
    TOK_FIND = 274,                /* "find"  */
    TOK_FOREACH = 275,             /* "foreach"  */
    TOK_IN = 276,                  /* "in"  */
    TOK_DELETE = 277,              /* "delete"  */
    TOK_REMOVE = 278,              /* "remove"  */
    TOK_PRIVATE = 279,             /* "private"  */
    TOK_PRIVATEINTERNAL = 280,     /* "private:internal"  */
    TOK_PRIVATEHIERARCHY = 281,    /* "private:hierarchy"  */
    TOK_PUBLIC = 282,              /* "public"  */
    TOK_SYNCHRONIZED = 283,        /* "synchronized"  */
    TOK_DEPRECATED = 284,          /* "deprecated"  */
    TOK_CONTEXT = 285,             /* "context"  */
    TOK_SORT_BY = 286,             /* "sortBy"  */
    TOK_SORT_DESCENDING_BY = 287,  /* "sortDescendingBy"  */
    TOK_SUB_CONTEXT = 288,         /* "subcontext"  */
    TOK_CONST = 289,               /* "const"  */
    TOK_SUMMARIZE = 290,           /* "summarize"  */
    TOK_BY = 291,                  /* "by"  */
    TOK_OUR = 292,                 /* "our"  */
    TOK_RETHROW = 293,             /* "rethrow"  */
    TOK_SWITCH = 294,              /* "switch"  */
    TOK_CASE = 295,                /* "case"  */
    TOK_DEFAULT = 296,             /* "default"  */
    TOK_INHERITS = 297,            /* "inherits"  */
    TOK_ELSE = 298,                /* "else"  */
    TOK_STATIC = 299,              /* "static"  */
    TOK_NAMESPACE = 300,           /* "namespace"  */
    TOK_MODULE = 301,              /* "module"  */
    TOK_FINAL = 302,               /* "final"  */
    TOK_ABSTRACT = 303,            /* "abstract"  */
    TOK_HASHDECL = 304,            /* "hashdecl"  */
    TOK_TRANSIENT = 305,           /* "transient"  */
    TOK_NULL = 306,                /* "NULL"  */
    TOK_NOTHING = 307,             /* "NOTHING"  */
    TOK_TRUE = 308,                /* "True"  */
    TOK_FALSE = 309,               /* "False"  */
    TOK_UNREFERENCE = 310,         /* "unreference"  */
    P_INCREMENT = 311,             /* "++ operator"  */
    P_DECREMENT = 312,             /* "-- operator"  */
    PLUS_EQUALS = 313,             /* "+= operator"  */
    MINUS_EQUALS = 314,            /* "-= operator"  */
    AND_EQUALS = 315,              /* "&= operator"  */
    OR_EQUALS = 316,               /* "|= operator"  */
    MODULA_EQUALS = 317,           /* "%= operator"  */
    MULTIPLY_EQUALS = 318,         /* "*= operator"  */
    DIVIDE_EQUALS = 319,           /* "/= operator"  */
    XOR_EQUALS = 320,              /* "^= operator"  */
    SHIFT_LEFT_EQUALS = 321,       /* "<<= operator"  */
    SHIFT_RIGHT_EQUALS = 322,      /* ">>= operator"  */
    TOK_UNSHIFT = 323,             /* "unshift"  */
    TOK_PUSH = 324,                /* "push"  */
    TOK_POP = 325,                 /* "pop"  */
    TOK_SHIFT = 326,               /* "shift"  */
    TOK_CHOMP = 327,               /* "chomp"  */
    TOK_TRIM = 328,                /* "trim"  */
    LOGICAL_AND = 329,             /* "&& operator"  */
    LOGICAL_OR = 330,              /* "|| operator"  */
    BROKEN_LOGICAL_OR = 331,       /* "|| operator (compat)"  */
    BROKEN_BINARY_OR = 332,        /* "| operator (compat)"  */
    BROKEN_BINARY_XOR = 333,       /* "^ operator (compat)"  */
    LOGICAL_EQ = 334,              /* "== operator"  */
    LOGICAL_NE = 335,              /* "!= operator"  */
    LOGICAL_LE = 336,              /* "<= operator"  */
    LOGICAL_GE = 337,              /* ">= operator"  */
    LOGICAL_CMP = 338,             /* "<=> operator"  */
    ABSOLUTE_EQ = 339,             /* "=== operator"  */
    ABSOLUTE_NE = 340,             /* "!== operator"  */
    REGEX_MATCH = 341,             /* "=~ operator"  */
    REGEX_NMATCH = 342,            /* "!~ operator"  */
    TOK_EXISTS = 343,              /* "exists"  */
    TOK_INSTANCEOF = 344,          /* "instanceof"  */
    SHIFT_RIGHT = 345,             /* ">> operator"  */
    SHIFT_LEFT = 346,              /* "<< operator"  */
    TOK_ELEMENTS = 347,            /* "elements"  */
    TOK_KEYS = 348,                /* "keys"  */
    TOK_NEW = 349,                 /* "new"  */
    TOK_BACKGROUND = 350,          /* "background"  */
    TOK_ON_EXIT = 351,             /* "on_exit"  */
    TOK_ON_SUCCESS = 352,          /* "on_success"  */
    TOK_ON_ERROR = 353,            /* "on_error"  */
    TOK_MAP = 354,                 /* "map"  */
    TOK_FOLDR = 355,               /* "foldr"  */
    TOK_FOLDL = 356,               /* "foldl"  */
    TOK_SELECT = 357,              /* "select"  */
    TOK_SPLICE = 358,              /* "splice"  */
    TOK_EXTRACT = 359,             /* "extract"  */
    IMPLICIT_ELEMENT = 360,        /* "$# operator"  */
    NULL_COALESCING = 361,         /* "?? operator"  */
    VALUE_COALESCING = 362,        /* "?* operator"  */
    WEAK_ASSIGNMENT = 363,         /* ":= operator"  */
    RANGE = 364,                   /* ".. operator"  */
    INTEGER = 365,                 /* "integer value"  */
    QFLOAT = 366,                  /* "floating-point value"  */
    NUMBER = 367,                  /* "arbitrary-precision number"  */
    IDENTIFIER = 368,              /* "identifier"  */
    HASHDECL_IDENTIFIER_OPENCURLY = 369, /* "typed hash identifier"  */
    ANGLE_IDENTIFIER = 370,        /* "complex type identifier"  */
    VAR_REF = 371,                 /* "variable reference"  */
    BACKQUOTE = 372,               /* "backquote expression"  */
    SELF_REF = 373,                /* "in-object member reference"  */
    KW_IDENTIFIER_OPENPAREN = 374, /* "identifier or keyword used as function or method identifier"  */
    SCOPED_REF = 375,              /* "namespace or class-scoped reference"  */
    SCOPED_VREF = 376,             /* "namespace-scoped global variable reference"  */
    CONTEXT_REF = 377,             /* "context reference"  */
    COMPLEX_CONTEXT_REF = 378,     /* "named context reference"  */
    QORE_CAST = 379,               /* "cast operator"  */
    QORE_OR_NOTHING_CAST = 380,    /* QORE_OR_NOTHING_CAST  */
    CLASS_STRING = 381,            /* "simple class declaration"  */
    DATETIME = 382,                /* "date/time value"  */
    QUOTED_WORD = 383,             /* "quoted string"  */
    BINARY = 384,                  /* "binary constant value"  */
    REGEX_SUBST = 385,             /* "regular expression substitution expression"  */
    REGEX_TRANS = 386,             /* "transliteration expression"  */
    CLASS_SCOPED_REF = 387,        /* "scoped class declaration"  */
    BASE_CLASS_CALL = 388,         /* "call to base class method"  */
    REGEX = 389,                   /* "regular expression"  */
    REGEX_EXTRACT = 390,           /* "regular expression extraction expression"  */
    IMPLICIT_ARG_REF = 391,        /* "implicit argument reference"  */
    DOT_KW_IDENTIFIER = 392,       /* "keyword used as hash key or object member reference"  */
    TRY_MODULE_ERROR = 393,        /* "%try-module error token"  */
    IFX = 394,                     /* IFX  */
    NEG = 395,                     /* NEG  */
    UPLUS = 396                    /* UPLUS  */
  };
  typedef enum yytokentype yytoken_kind_t;
#endif
/* Token kinds.  */
#define YYEOF 0
#define YYerror 256
#define YYUNDEF 257
#define TOK_RETURN 258
#define TOK_RETURNS 259
#define TOK_MY 260
#define TOK_DO 261
#define TOK_TRY 262
#define TOK_THROW 263
#define TOK_CATCH 264
#define TOK_WHERE 265
#define TOK_WHILE 266
#define TOK_IF 267
#define TOK_FOR 268
#define TOK_SUB 269
#define TOK_THREAD_EXIT 270
#define TOK_BREAK 271
#define TOK_CONTINUE 272
#define TOK_CONTEXT_ROW 273
#define TOK_FIND 274
#define TOK_FOREACH 275
#define TOK_IN 276
#define TOK_DELETE 277
#define TOK_REMOVE 278
#define TOK_PRIVATE 279
#define TOK_PRIVATEINTERNAL 280
#define TOK_PRIVATEHIERARCHY 281
#define TOK_PUBLIC 282
#define TOK_SYNCHRONIZED 283
#define TOK_DEPRECATED 284
#define TOK_CONTEXT 285
#define TOK_SORT_BY 286
#define TOK_SORT_DESCENDING_BY 287
#define TOK_SUB_CONTEXT 288
#define TOK_CONST 289
#define TOK_SUMMARIZE 290
#define TOK_BY 291
#define TOK_OUR 292
#define TOK_RETHROW 293
#define TOK_SWITCH 294
#define TOK_CASE 295
#define TOK_DEFAULT 296
#define TOK_INHERITS 297
#define TOK_ELSE 298
#define TOK_STATIC 299
#define TOK_NAMESPACE 300
#define TOK_MODULE 301
#define TOK_FINAL 302
#define TOK_ABSTRACT 303
#define TOK_HASHDECL 304
#define TOK_TRANSIENT 305
#define TOK_NULL 306
#define TOK_NOTHING 307
#define TOK_TRUE 308
#define TOK_FALSE 309
#define TOK_UNREFERENCE 310
#define P_INCREMENT 311
#define P_DECREMENT 312
#define PLUS_EQUALS 313
#define MINUS_EQUALS 314
#define AND_EQUALS 315
#define OR_EQUALS 316
#define MODULA_EQUALS 317
#define MULTIPLY_EQUALS 318
#define DIVIDE_EQUALS 319
#define XOR_EQUALS 320
#define SHIFT_LEFT_EQUALS 321
#define SHIFT_RIGHT_EQUALS 322
#define TOK_UNSHIFT 323
#define TOK_PUSH 324
#define TOK_POP 325
#define TOK_SHIFT 326
#define TOK_CHOMP 327
#define TOK_TRIM 328
#define LOGICAL_AND 329
#define LOGICAL_OR 330
#define BROKEN_LOGICAL_OR 331
#define BROKEN_BINARY_OR 332
#define BROKEN_BINARY_XOR 333
#define LOGICAL_EQ 334
#define LOGICAL_NE 335
#define LOGICAL_LE 336
#define LOGICAL_GE 337
#define LOGICAL_CMP 338
#define ABSOLUTE_EQ 339
#define ABSOLUTE_NE 340
#define REGEX_MATCH 341
#define REGEX_NMATCH 342
#define TOK_EXISTS 343
#define TOK_INSTANCEOF 344
#define SHIFT_RIGHT 345
#define SHIFT_LEFT 346
#define TOK_ELEMENTS 347
#define TOK_KEYS 348
#define TOK_NEW 349
#define TOK_BACKGROUND 350
#define TOK_ON_EXIT 351
#define TOK_ON_SUCCESS 352
#define TOK_ON_ERROR 353
#define TOK_MAP 354
#define TOK_FOLDR 355
#define TOK_FOLDL 356
#define TOK_SELECT 357
#define TOK_SPLICE 358
#define TOK_EXTRACT 359
#define IMPLICIT_ELEMENT 360
#define NULL_COALESCING 361
#define VALUE_COALESCING 362
#define WEAK_ASSIGNMENT 363
#define RANGE 364
#define INTEGER 365
#define QFLOAT 366
#define NUMBER 367
#define IDENTIFIER 368
#define HASHDECL_IDENTIFIER_OPENCURLY 369
#define ANGLE_IDENTIFIER 370
#define VAR_REF 371
#define BACKQUOTE 372
#define SELF_REF 373
#define KW_IDENTIFIER_OPENPAREN 374
#define SCOPED_REF 375
#define SCOPED_VREF 376
#define CONTEXT_REF 377
#define COMPLEX_CONTEXT_REF 378
#define QORE_CAST 379
#define QORE_OR_NOTHING_CAST 380
#define CLASS_STRING 381
#define DATETIME 382
#define QUOTED_WORD 383
#define BINARY 384
#define REGEX_SUBST 385
#define REGEX_TRANS 386
#define CLASS_SCOPED_REF 387
#define BASE_CLASS_CALL 388
#define REGEX 389
#define REGEX_EXTRACT 390
#define IMPLICIT_ARG_REF 391
#define DOT_KW_IDENTIFIER 392
#define TRY_MODULE_ERROR 393
#define IFX 394
#define NEG 395
#define UPLUS 396

/* Value type.  */
#if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
union YYSTYPE
{
#line 1512 "parser.ypp"

    QoreSimpleValue qv;
    bool b;
    int i4;
    int64 integer;
    double decimal;
    QoreStringNode* String;
    char* string;
    BinaryNode* binary;
    AbstractQoreNode* node;
    QoreParseHashNode* hash;
    QoreParseListNode* parse_list;
    AbstractStatement* statement;
    struct MemberInfo* memberinfo;
    struct ClassVarInfo* classvarinfo;
    StatementBlock *sblock;
    ContextModList* cmods;
    ContextMod *cmod;
    class HashElement* hashelement;
    QoreFunction* userfunc;
    struct MethodNode* methodnode;
    class MemberList* memberlist;
    QoreClass* qoreclass;
    typed_hash_decl_private* hashdeclpriv;
    class ConstNode* constnode;
    QoreNamespace *ns;
    struct NSNodeList* nsnlist;
    struct NSNode* nsn;
    class ObjClassDef* classdef;
    class HashDeclDef* hashdecldef;
    DateTimeNode* datetime;
    QoreRegexSubst* RegexSubst;
    QoreTransliteration* Trans;
    SwitchStatement* switchstmt;
    CaseNode* casenode;
    BCList* sclist;
    class BCNode* sclnode;
    BCAList* bcalist;
    BCANode* bcanode;
    NamedScope *nscope;
    QoreRegex* Regex;
    QoreImplicitArgumentNode* implicit_arg;
    RetTypeInfo* returnTypeInfo;
    struct ParserTypeStruct* parsertype;
    class ParseUserFunction* parsefunc;
    class ParseScopedUserFunction* sparsefunc;
    struct GVarDecl* gv;
    QoreNumberNode* num;
    TryModuleError* trymod;
    struct MethodDef* methoddef;

#line 400 "parser.hpp"

};
typedef union YYSTYPE YYSTYPE;
# define YYSTYPE_IS_TRIVIAL 1
# define YYSTYPE_IS_DECLARED 1
#endif

/* Location type.  */
#if ! defined YYLTYPE && ! defined YYLTYPE_IS_DECLARED
typedef struct YYLTYPE YYLTYPE;
struct YYLTYPE
{
  int first_line;
  int first_column;
  int last_line;
  int last_column;
};
# define YYLTYPE_IS_DECLARED 1
# define YYLTYPE_IS_TRIVIAL 1
#endif



int yyparse (yyscan_t yyscanner);

#endif /* !YY_YY_PARSER_HPP_INCLUDED  */

==> qore-0.9.4.6.tar.bz2: qore-0.9.4.6/lib/parser.hpp <==
/* A Bison parser, made by GNU Bison 3.5.  */

/* Bison interface for Yacc-like parsers in C

   Copyright (C) 1984, 1989-1990, 2000-2015, 2018-2019 Free Software Foundation,
   Inc.

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */

/* As a special exception, you may create a larger work that contains
   part or all of the Bison parser skeleton and distribute that work
   under terms of your choice, so long as that work isn't itself a
   parser generator using the skeleton or a modified version thereof
   as a parser skeleton.  Alternatively, if you modify or redistribute
   the parser skeleton itself, you may (at your option) remove this
   special exception, which will cause the skeleton and the resulting
   Bison output files to be licensed under the GNU General Public
   License without this special exception.

   This special exception was added by the Free Software Foundation in
   version 2.2 of Bison.  */

/* Undocumented macros, especially those whose name start with YY_,
   are private implementation details.  Do not rely on them.  */

#ifndef YY_YY_PARSER_HPP_INCLUDED
# define YY_YY_PARSER_HPP_INCLUDED
/* Debug traces.  */
#ifndef YYDEBUG
# define YYDEBUG 0
#endif
#if YYDEBUG
extern int yydebug;
#endif

/* Token type.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
  enum yytokentype
  {
    TOK_RETURN = 258,
    TOK_RETURNS = 259,
    TOK_MY = 260,
    TOK_DO = 261,
    TOK_TRY = 262,
    TOK_THROW = 263,
    TOK_CATCH = 264,
    TOK_WHERE = 265,
    TOK_WHILE = 266,
    TOK_IF = 267,
    TOK_FOR = 268,
    TOK_SUB = 269,
    TOK_THREAD_EXIT = 270,
    TOK_BREAK = 271,
    TOK_CONTINUE = 272,
    TOK_CONTEXT_ROW = 273,
    TOK_FIND = 274,
    TOK_FOREACH = 275,
    TOK_IN = 276,
    TOK_DELETE = 277,
    TOK_REMOVE = 278,
    TOK_PRIVATE = 279,
    TOK_PRIVATEINTERNAL = 280,
    TOK_PRIVATEHIERARCHY = 281,
    TOK_PUBLIC = 282,
    TOK_SYNCHRONIZED = 283,
    TOK_DEPRECATED = 284,
    TOK_CONTEXT = 285,
    TOK_SORT_BY = 286,
    TOK_SORT_DESCENDING_BY = 287,
    TOK_SUB_CONTEXT = 288,
    TOK_CONST = 289,
    TOK_SUMMARIZE = 290,
    TOK_BY = 291,
    TOK_OUR = 292,
    TOK_RETHROW = 293,
    TOK_SWITCH = 294,
    TOK_CASE = 295,
    TOK_DEFAULT = 296,
    TOK_INHERITS = 297,
    TOK_ELSE = 298,
    TOK_STATIC = 299,
    TOK_NAMESPACE = 300,
    TOK_MODULE = 301,
    TOK_FINAL = 302,
    TOK_ABSTRACT = 303,
    TOK_HASHDECL = 304,
    TOK_TRANSIENT = 305,
    TOK_NULL = 306,
    TOK_NOTHING = 307,
    TOK_TRUE = 308,
    TOK_FALSE = 309,
    TOK_UNREFERENCE = 310,
    P_INCREMENT = 311,
    P_DECREMENT = 312,
    PLUS_EQUALS = 313,
    MINUS_EQUALS = 314,
    AND_EQUALS = 315,
    OR_EQUALS = 316,
    MODULA_EQUALS = 317,
    MULTIPLY_EQUALS = 318,
    DIVIDE_EQUALS = 319,
    XOR_EQUALS = 320,
    SHIFT_LEFT_EQUALS = 321,
    SHIFT_RIGHT_EQUALS = 322,
    TOK_UNSHIFT = 323,
    TOK_PUSH = 324,
    TOK_POP = 325,
    TOK_SHIFT = 326,
    TOK_CHOMP = 327,
    TOK_TRIM = 328,
    LOGICAL_AND = 329,
    LOGICAL_OR = 330,
    BROKEN_LOGICAL_OR = 331,
    BROKEN_BINARY_OR = 332,
    BROKEN_BINARY_XOR = 333,
    LOGICAL_EQ = 334,
    LOGICAL_NE = 335,
    LOGICAL_LE = 336,
    LOGICAL_GE = 337,
    LOGICAL_CMP = 338,
    ABSOLUTE_EQ = 339,
    ABSOLUTE_NE = 340,
    REGEX_MATCH = 341,
    REGEX_NMATCH = 342,
    TOK_EXISTS = 343,
    TOK_INSTANCEOF = 344,
    SHIFT_RIGHT = 345,
    SHIFT_LEFT = 346,
    TOK_ELEMENTS = 347,
    TOK_KEYS = 348,
    TOK_NEW = 349,
    TOK_BACKGROUND = 350,
    TOK_ON_EXIT = 351,
    TOK_ON_SUCCESS = 352,
    TOK_ON_ERROR = 353,
    TOK_MAP = 354,
    TOK_FOLDR = 355,
    TOK_FOLDL = 356,
    TOK_SELECT = 357,
    TOK_SPLICE = 358,
    TOK_EXTRACT = 359,
    IMPLICIT_ELEMENT = 360,
    NULL_COALESCING = 361,
    VALUE_COALESCING = 362,
    WEAK_ASSIGNMENT = 363,
    RANGE = 364,
    INTEGER = 365,
    QFLOAT = 366,
    NUMBER = 367,
    IDENTIFIER = 368,
    HASHDECL_IDENTIFIER_OPENCURLY = 369,
    ANGLE_IDENTIFIER = 370,
    VAR_REF = 371,
    BACKQUOTE = 372,
    SELF_REF = 373,
    KW_IDENTIFIER_OPENPAREN = 374,
    SCOPED_REF = 375,
    SCOPED_VREF = 376,
    CONTEXT_REF = 377,
    COMPLEX_CONTEXT_REF = 378,
    QORE_CAST = 379,
    QORE_OR_NOTHING_CAST = 380,
    CLASS_STRING = 381,
    DATETIME = 382,
    QUOTED_WORD = 383,
    BINARY = 384,
    REGEX_SUBST = 385,
    REGEX_TRANS = 386,
    CLASS_SCOPED_REF = 387,
    BASE_CLASS_CALL = 388,
    REGEX = 389,
    REGEX_EXTRACT = 390,
    IMPLICIT_ARG_REF = 391,
    DOT_KW_IDENTIFIER = 392,
    TRY_MODULE_ERROR = 393,
    IFX = 394,
    NEG = 395,
    UPLUS = 396
  };
#endif
/* Tokens.  */
#define TOK_RETURN 258
#define TOK_RETURNS 259
#define TOK_MY 260
#define TOK_DO 261
#define TOK_TRY 262
#define TOK_THROW 263
#define TOK_CATCH 264
#define TOK_WHERE 265
#define TOK_WHILE 266
#define TOK_IF 267
#define TOK_FOR 268
#define TOK_SUB 269
#define TOK_THREAD_EXIT 270
#define TOK_BREAK 271
#define TOK_CONTINUE 272
#define TOK_CONTEXT_ROW 273
#define TOK_FIND 274
#define TOK_FOREACH 275
#define TOK_IN 276
#define TOK_DELETE 277
#define TOK_REMOVE 278
#define TOK_PRIVATE 279
#define TOK_PRIVATEINTERNAL 280
#define TOK_PRIVATEHIERARCHY 281
#define TOK_PUBLIC 282
#define TOK_SYNCHRONIZED 283
#define TOK_DEPRECATED 284
#define TOK_CONTEXT 285
#define TOK_SORT_BY 286
#define TOK_SORT_DESCENDING_BY 287
#define TOK_SUB_CONTEXT 288
#define TOK_CONST 289
#define TOK_SUMMARIZE 290
#define TOK_BY 291
#define TOK_OUR 292
#define TOK_RETHROW 293
#define TOK_SWITCH 294
#define TOK_CASE 295
#define TOK_DEFAULT 296
#define TOK_INHERITS 297
#define TOK_ELSE 298
#define TOK_STATIC 299
#define TOK_NAMESPACE 300
#define TOK_MODULE 301
#define TOK_FINAL 302
#define TOK_ABSTRACT 303
#define TOK_HASHDECL 304
#define TOK_TRANSIENT 305
#define TOK_NULL 306
#define TOK_NOTHING 307
#define TOK_TRUE 308
#define TOK_FALSE 309
#define TOK_UNREFERENCE 310
#define P_INCREMENT 311
#define P_DECREMENT 312
#define PLUS_EQUALS 313
#define MINUS_EQUALS 314
#define AND_EQUALS 315
#define OR_EQUALS 316
#define MODULA_EQUALS 317
#define MULTIPLY_EQUALS 318
#define DIVIDE_EQUALS 319
#define XOR_EQUALS 320
#define SHIFT_LEFT_EQUALS 321
#define SHIFT_RIGHT_EQUALS 322
#define TOK_UNSHIFT 323
#define TOK_PUSH 324
#define TOK_POP 325
#define TOK_SHIFT 326
#define TOK_CHOMP 327
#define TOK_TRIM 328
#define LOGICAL_AND 329
#define LOGICAL_OR 330
#define BROKEN_LOGICAL_OR 331
#define BROKEN_BINARY_OR 332
#define BROKEN_BINARY_XOR 333
#define LOGICAL_EQ 334
#define LOGICAL_NE 335
#define LOGICAL_LE 336
#define LOGICAL_GE 337
#define LOGICAL_CMP 338
#define ABSOLUTE_EQ 339
#define ABSOLUTE_NE 340
#define REGEX_MATCH 341
#define REGEX_NMATCH 342
#define TOK_EXISTS 343
#define TOK_INSTANCEOF 344
#define SHIFT_RIGHT 345
#define SHIFT_LEFT 346
#define TOK_ELEMENTS 347
#define TOK_KEYS 348
#define TOK_NEW 349
#define TOK_BACKGROUND 350
#define TOK_ON_EXIT 351
#define TOK_ON_SUCCESS 352
#define TOK_ON_ERROR 353
#define TOK_MAP 354
#define TOK_FOLDR 355
#define TOK_FOLDL 356
#define TOK_SELECT 357
#define TOK_SPLICE 358
#define TOK_EXTRACT 359
#define IMPLICIT_ELEMENT 360
#define NULL_COALESCING 361
#define VALUE_COALESCING 362
#define WEAK_ASSIGNMENT 363
#define RANGE 364
#define INTEGER 365
#define QFLOAT 366
#define NUMBER 367
#define IDENTIFIER 368
#define HASHDECL_IDENTIFIER_OPENCURLY 369
#define ANGLE_IDENTIFIER 370
#define VAR_REF 371
#define BACKQUOTE 372
#define SELF_REF 373
#define KW_IDENTIFIER_OPENPAREN 374
#define SCOPED_REF 375
#define SCOPED_VREF 376
#define CONTEXT_REF 377
#define COMPLEX_CONTEXT_REF 378
#define QORE_CAST 379
#define QORE_OR_NOTHING_CAST 380
#define CLASS_STRING 381
#define DATETIME 382
#define QUOTED_WORD 383
#define BINARY 384
#define REGEX_SUBST 385
#define REGEX_TRANS 386
#define CLASS_SCOPED_REF 387
#define BASE_CLASS_CALL 388
#define REGEX 389
#define REGEX_EXTRACT 390
#define IMPLICIT_ARG_REF 391
#define DOT_KW_IDENTIFIER 392
#define TRY_MODULE_ERROR 393
#define IFX 394
#define NEG 395
#define UPLUS 396

/* Value type.  */
#if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
union YYSTYPE
{
#line 1512 "parser.ypp"

    QoreSimpleValue qv;
    bool b;
    int i4;
    int64 integer;
    double decimal;
    QoreStringNode* String;
    char* string;
    BinaryNode* binary;
    AbstractQoreNode* node;
    QoreParseHashNode* hash;
    QoreParseListNode* parse_list;
    AbstractStatement* statement;
    struct MemberInfo* memberinfo;
    struct ClassVarInfo* classvarinfo;
    StatementBlock *sblock;
    ContextModList* cmods;
    ContextMod *cmod;
    class HashElement* hashelement;
    QoreFunction* userfunc;
    struct MethodNode* methodnode;
    class MemberList* memberlist;
    QoreClass* qoreclass;
    typed_hash_decl_private* hashdeclpriv;
    class ConstNode* constnode;
    QoreNamespace *ns;
    struct NSNodeList* nsnlist;
    struct NSNode* nsn;
    class ObjClassDef* classdef;
    class HashDeclDef* hashdecldef;
    DateTimeNode* datetime;
    QoreRegexSubst* RegexSubst;
    QoreTransliteration* Trans;
    SwitchStatement* switchstmt;
    CaseNode* casenode;
    BCList* sclist;
    class BCNode* sclnode;
    BCAList* bcalist;
    BCANode* bcanode;
    NamedScope *nscope;
    QoreRegex* Regex;
    QoreImplicitArgumentNode* implicit_arg;
    RetTypeInfo* returnTypeInfo;
    struct ParserTypeStruct* parsertype;
    class ParseUserFunction* parsefunc;
    class ParseScopedUserFunction* sparsefunc;
    struct GVarDecl* gv;
    QoreNumberNode* num;
    TryModuleError* trymod;
    struct MethodDef* methoddef;

#line 391 "parser.hpp"

};
typedef union YYSTYPE YYSTYPE;
# define YYSTYPE_IS_TRIVIAL 1
# define YYSTYPE_IS_DECLARED 1
#endif

/* Location type.  */
#if ! defined YYLTYPE && ! defined YYLTYPE_IS_DECLARED
typedef struct YYLTYPE YYLTYPE;
struct YYLTYPE
{
  int first_line;
  int first_column;
  int last_line;
  int last_column;
};
# define YYLTYPE_IS_DECLARED 1
# define YYLTYPE_IS_TRIVIAL 1
#endif



int yyparse (yyscan_t yyscanner);

#endif /* !YY_YY_PARSER_HPP_INCLUDED  */
